jacinle.config.environ
======================

.. automodule:: jacinle.config.environ

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      Environ
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      get_env
      has_env
      load_env
      set_env
      update_env
      with_env
   
   

   
   
   








.. rubric:: Class Environ
.. autoclass:: Environ
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: get_env

.. autofunction:: has_env

.. autofunction:: load_env

.. autofunction:: set_env

.. autofunction:: update_env

.. autofunction:: with_env


